@@ -1,5 +1,15 @@
 //! Contains constants and data used by this tool to generate the initial cargo package.
 
+use crate::shared::{
+    PACKAGE_DISPLAY_NAME_DEFAULT, PACKAGE_DISPLAY_NAME_KEY, PACKAGE_IDENTITY_NAME_DEFAULT,
+    PACKAGE_IDENTITY_NAME_KEY, PACKAGE_IDENTITY_PUBLISHER_DEFAULT, PACKAGE_IDENTITY_PUBLISHER_KEY,
+    PACKAGE_IDENTITY_VERSION_DEFAULT, PACKAGE_IDENTITY_VERSION_KEY, PACKAGE_PHONE_ID_DEFAULT,
+    PACKAGE_PHONE_ID_KEY, PACKAGE_PUBLISHER_DISPLAY_NAME_DEFAULT,
+    PACKAGE_PUBLISHER_DISPLAY_NAME_KEY, PACKAGE_VISUAL_DESCRIPTION_DEFAULT,
+    PACKAGE_VISUAL_DESCRIPTION_KEY, PACKAGE_VISUAL_DISPLAY_NAME_DEFAULT,
+    PACKAGE_VISUAL_DISPLAY_NAME_KEY,
+};
+
 /// Version of the *window-rs* crate to be used. This version is used in the
 /// `[dependencies]` table of the cargo package, as well as in the *bindings* crate.
 ///
@@ -52,8 +62,13 @@ pub(crate) const FILE_MAPPINGS_TEMPLATE_FILENAME: &str = "FileMapping.ini";
 
 /// Build system
 ///
-pub(crate) const BUILD_RS: &[u8] = include_bytes!("../data/build.rs");
-pub(crate) const BUILD_RS_FILENAME: &str = "build.rs";
+pub(crate) const BUILD_DIR: &str = ".build";
+
+pub(crate) const BUILD_RS: &[u8] = include_bytes!("../data/.build/main.rs");
+pub(crate) const BUILD_RS_FILENAME: &str = "main.rs";
+
+pub(crate) const SHARED_RS: &[u8] = include_bytes!("shared.rs");
+pub(crate) const SHARED_RS_FILENAME: &str = "shared.rs";
 
 /// Package metatdata table used by the build system and this tool
 ///
@@ -65,7 +80,6 @@ pub(crate) const BUILD_RS_FILENAME: &str = "build.rs";
 pub(crate) const PACKAGE_METADATA_INIT: &str = r#"
 [build-dependencies]
 toml = "0.5.8"
-cargo-uwp = "0.2.0"
 
 
 # Metadata driving the build system. Once created, you can freely fill in and change the
@@ -91,7 +105,7 @@ $package-identity-publisher$
 # binary artifacts generated by the build system.
 # When missing, this value is substituted with the "version" entry of the [package]
 # table, with the <Revision> field defaulting to 0.
-# package-identity-version = "0.0.0.0"
+# $package-identity-version$
 
 
 # The following entry controls whether to target Windows 10 Mobile.
@@ -99,7 +113,7 @@ $package-identity-publisher$
 # (String, optional) The phone product ID: A string representing the GUID of the Windows
 # 10 Mobile product. It is required when targeting Windows 10 Mobile.
 # When missing, no packages targeting Windows 10 Mobile are generated.
-# package-phoneidentity-productid = "00000000-0000-0000-0000-000000000000"
+# $package-phoneidentity-productid$
 
 
 # The next two entries designate public-facing properties of the application. Either one
@@ -108,7 +122,7 @@ $package-identity-publisher$
 # (String, optional) The package display name: This property must match the application
 # name as registered in the Microsoft Partner Center. When missing, this value is
 # substituted with the "name" entry of the [package] table.
-# package-properties-displayname = "<app name>"
+# $package-properties-displayname$
 
 # (String, required) The package publisher display name: This property must match the
 # publisher display name under which you plan to publish an application in the Microsoft
@@ -133,6 +147,12 @@ $package-applications-visualelements-description$
 pub(crate) const PACKAGE_IDENTITY_NAME_PLACEHOLDER: &str = "$package-identity-name$";
 /// $package-identity-publisher$ => PACKAGE_IDENTITY_PUBLISHER_KEY = "PACKAGE_IDENTITY_PUBLISHER_DEFAULT"
 pub(crate) const PACKAGE_IDENTITY_PUBLISHER_PLACEHOLDER: &str = "$package-identity-publisher$";
+/// $package-identity-version$ => PACKAGE_IDENTITY_VERSION_KEY = "PACKAGE_IDENTITY_VERSION_DEFAULT"
+pub(crate) const PACKAGE_IDENTITY_VERSION_PLACEHOLDER: &str = "$package-identity-version$";
+/// $package-phoneidentity-productid$ => PACKAGE_PHONE_ID_KEY = "PACKAGE_PHONE_ID_DEFAULT"
+pub(crate) const PACKAGE_PHONE_ID_PLACEHOLDER: &str = "$package-phoneidentity-productid$";
+/// $package-properties-displayname$ => PACKAGE_DISPLAY_NAME_KEY = "PACKAGE_DISPLAY_NAME_DEFAULT"
+pub(crate) const PACKAGE_DISPLAY_NAME_PLACEHOLDER: &str = "$package-properties-displayname$";
 /// $package-properties-publisherdisplayname$ => PACKAGE_PUBLISHER_DISPLAY_NAME_KEY = "PACKAGE_PUBLISHER_DISPLAY_NAME_DEFAULT"
 pub(crate) const PACKAGE_PUBLISHER_DISPLAY_NAME_PLACEHOLDER: &str =
     "$package-properties-publisherdisplayname$";
@@ -142,6 +162,57 @@ pub(crate) const PACKAGE_VISUAL_DISPLAY_NAME_PLACEHOLDER: &str =
 /// $package-applications-visualelements-description$ => PACKAGE_VISUAL_DESCRIPTION_KEY = "PACKAGE_VISUAL_DESCRIPTION_DEFAULT"
 pub(crate) const PACKAGE_VISUAL_DESCRIPTION_PLACEHOLDER: &str =
     "$package-applications-visualelements-description$";
+/// Array of mappings between `(placeholder, (key, default_value))`. `placeholder` in the
+/// source string gets replaced with `key = "default_value"`.
+pub(crate) const METADATA_PLACEHOLDERS: &[(&str, (&str, &str))] = &[
+    (
+        PACKAGE_IDENTITY_NAME_PLACEHOLDER,
+        (PACKAGE_IDENTITY_NAME_KEY, PACKAGE_IDENTITY_NAME_DEFAULT),
+    ),
+    (
+        PACKAGE_IDENTITY_PUBLISHER_PLACEHOLDER,
+        (
+            PACKAGE_IDENTITY_PUBLISHER_KEY,
+            PACKAGE_IDENTITY_PUBLISHER_DEFAULT,
+        ),
+    ),
+    (
+        PACKAGE_IDENTITY_VERSION_PLACEHOLDER,
+        (
+            PACKAGE_IDENTITY_VERSION_KEY,
+            PACKAGE_IDENTITY_VERSION_DEFAULT,
+        ),
+    ),
+    (
+        PACKAGE_PHONE_ID_PLACEHOLDER,
+        (PACKAGE_PHONE_ID_KEY, PACKAGE_PHONE_ID_DEFAULT),
+    ),
+    (
+        PACKAGE_DISPLAY_NAME_PLACEHOLDER,
+        (PACKAGE_DISPLAY_NAME_KEY, PACKAGE_DISPLAY_NAME_DEFAULT),
+    ),
+    (
+        PACKAGE_PUBLISHER_DISPLAY_NAME_PLACEHOLDER,
+        (
+            PACKAGE_PUBLISHER_DISPLAY_NAME_KEY,
+            PACKAGE_PUBLISHER_DISPLAY_NAME_DEFAULT,
+        ),
+    ),
+    (
+        PACKAGE_VISUAL_DISPLAY_NAME_PLACEHOLDER,
+        (
+            PACKAGE_VISUAL_DISPLAY_NAME_KEY,
+            PACKAGE_VISUAL_DISPLAY_NAME_DEFAULT,
+        ),
+    ),
+    (
+        PACKAGE_VISUAL_DESCRIPTION_PLACEHOLDER,
+        (
+            PACKAGE_VISUAL_DESCRIPTION_KEY,
+            PACKAGE_VISUAL_DESCRIPTION_DEFAULT,
+        ),
+    ),
+];
 
 /// Bindings crate
 ///
